@@ -407,6 +407,8 @@ class EngineService(service.Service):
 
     def _stop_rpc_server(self):
         # Stop rpc connection at first for preventing new requests
+        if self._rpc_server is None:
+            return
         LOG.debug("Attempting to stop engine service...")
         try:
             self._rpc_server.stop()
@@ -423,20 +425,21 @@ class EngineService(service.Service):
             self.worker_service.stop()
 
         # Wait for all active threads to be finished
-        for stack_id in list(self.thread_group_mgr.groups.keys()):
-            # Ignore dummy service task
-            if stack_id == cfg.CONF.periodic_interval:
-                continue
-            LOG.info(_LI("Waiting stack %s processing to be finished"),
-                     stack_id)
-            # Stop threads gracefully
-            self.thread_group_mgr.stop(stack_id, True)
-            LOG.info(_LI("Stack %s processing was finished"), stack_id)
-
-        self.manage_thread_grp.stop()
-        ctxt = context.get_admin_context()
-        service_objects.Service.delete(ctxt, self.service_id)
-        LOG.info(_LI('Service %s is deleted'), self.service_id)
+        if self.thread_group_mgr:
+            for stack_id in list(self.thread_group_mgr.groups.keys()):
+                # Ignore dummy service task
+                if stack_id == cfg.CONF.periodic_interval:
+                    continue
+                LOG.info(_LI("Waiting stack %s processing to be finished"),
+                         stack_id)
+                # Stop threads gracefully
+                self.thread_group_mgr.stop(stack_id, True)
+                LOG.info(_LI("Stack %s processing was finished"), stack_id)
+        if self.manage_thread_grp:
+            self.manage_thread_grp.stop()
+            ctxt = context.get_admin_context()
+            service_objects.Service.delete(ctxt, self.service_id)
+            LOG.info(_LI('Service %s is deleted'), self.service_id)
 
         # Terminate the engine process
         LOG.info(_LI("All threads were gone, terminating engine"))
@@ -1458,7 +1461,7 @@ class EngineService(service.Service):
             raise exception.InvalidGlobalResource(type_name=type_name)
 
         if resource_class.support_status.status == support.HIDDEN:
-            raise exception.NotSupported(type_name)
+            raise exception.NotSupported(feature=type_name)
 
         try:
             svc_available = resource_class.is_service_available(cnxt)
@@ -1477,7 +1480,8 @@ class EngineService(service.Service):
         def properties_schema():
             for name, schema_dict in resource_class.properties_schema.items():
                 schema = properties.Schema.from_legacy(schema_dict)
-                if schema.implemented:
+                if (schema.implemented
+                        and schema.support_status.status != support.HIDDEN):
                     yield name, dict(schema)
 
         def attributes_schema():
@@ -1485,7 +1489,8 @@ class EngineService(service.Service):
                     resource_class.attributes_schema.items(),
                     resource_class.base_attributes_schema.items()):
                 schema = attributes.Schema.from_attribute(schema_data)
-                yield name, dict(schema)
+                if schema.support_status.status != support.HIDDEN:
+                    yield name, dict(schema)
 
         return {
             rpc_api.RES_SCHEMA_RES_TYPE: type_name,
@@ -1512,7 +1517,7 @@ class EngineService(service.Service):
             raise exception.InvalidGlobalResource(type_name=type_name)
         else:
             if resource_class.support_status.status == support.HIDDEN:
-                raise exception.NotSupported(type_name)
+                raise exception.NotSupported(feature=type_name)
             return resource_class.resource_to_template(type_name,
                                                        template_type)
 
@@ -1741,10 +1746,24 @@ class EngineService(service.Service):
         s = self._get_stack(cnxt, stack_identity, show_deleted=True)
         stack = parser.Stack.load(cnxt, stack=s)
         depth = min(nested_depth, cfg.CONF.max_nested_stack_depth)
+        res_type = None
+        if filters is not None:
+            filters = api.translate_filters(filters)
+            # There is not corresponding for `type` column in Resource table,
+            # so sqlalchemy filters can't be used.
+            res_type = filters.pop('type', None)
 
+        def filter_type(res_iter):
+            for res in res_iter:
+                if res_type not in res.type():
+                    continue
+                yield res
+        if res_type is None:
+            rsrcs = stack.iter_resources(depth, filters=filters)
+        else:
+            rsrcs = filter_type(stack.iter_resources(depth, filters=filters))
         return [api.format_stack_resource(resource, detail=with_detail)
-                for resource in stack.iter_resources(depth,
-                                                     filters=filters)]
+                for resource in rsrcs]
 
     @context.request_context
     def stack_suspend(self, cnxt, stack_identity):
@@ -2107,8 +2126,6 @@ class EngineService(service.Service):
                 service_objects.Service.delete(cnxt, service_ref['id'])
 
     def set_stack_and_resource_to_failed(self, stack):
-        reason = ('Engine went down during stack %s' % stack.action)
-        stack.state_set(stack.action, stack.FAILED, six.text_type(reason))
         for name, rsrc in six.iteritems(stack.resources):
             if rsrc.status == rsrc.IN_PROGRESS:
                 status_reason = ('Engine went down '
@@ -2116,6 +2133,8 @@ class EngineService(service.Service):
                 rsrc.state_set(rsrc.action,
                                rsrc.FAILED,
                                six.text_type(status_reason))
+        reason = ('Engine went down during stack %s' % stack.action)
+        stack.state_set(stack.action, stack.FAILED, six.text_type(reason))
 
     def reset_stack_status(self):
         cnxt = context.get_admin_context()
