@@ -21,6 +21,7 @@ from heat.engine.resources.openstack.keystone import role_assignments
 from heat.engine import stack
 from heat.engine import template
 from heat.tests import common
+from heat.tests import fakes
 from heat.tests import generic_resource
 from heat.tests import utils
 
@@ -415,9 +416,10 @@ class KeystoneUserRoleAssignmentTest(common.HeatTestCase):
         self.test_role_assignment = self.stack['test_role_assignment']
 
         # Mock client
-        self.keystoneclient = mock.MagicMock()
-        self.test_role_assignment.client = mock.MagicMock()
-        self.test_role_assignment.client.return_value = self.keystoneclient
+        self.keystoneclient = mock.Mock()
+        self.patchobject(resource.Resource, 'client',
+                         return_value=fakes.FakeKeystoneClient(
+                             client=self.keystoneclient))
         self.roles = self.keystoneclient.roles
 
         # Mock client plugin
@@ -553,9 +555,10 @@ class KeystoneGroupRoleAssignmentTest(common.HeatTestCase):
         self.test_role_assignment = self.stack['test_role_assignment']
 
         # Mock client
-        self.keystoneclient = mock.MagicMock()
-        self.test_role_assignment.client = mock.MagicMock()
-        self.test_role_assignment.client.return_value = self.keystoneclient
+        self.keystoneclient = mock.Mock()
+        self.patchobject(resource.Resource, 'client',
+                         return_value=fakes.FakeKeystoneClient(
+                             client=self.keystoneclient))
         self.roles = self.keystoneclient.roles
 
         # Mock client plugin
