@@ -31,7 +31,13 @@ nova flavor-create m1.heat_int 452 512 0 1
 nova flavor-create m1.heat_micro 453 128 0 1
 
 # Register the glance image for testing
-curl http://tarballs.openstack.org/heat-test-image/fedora-heat-test-image.qcow2 | glance image-create --name fedora-heat-test-image --disk-format qcow2 --container-format bare --visibility public
+curl -L https://download.fedoraproject.org/pub/fedora/linux/releases/24/CloudImages/x86_64/images/Fedora-Cloud-Base-24-1.2.x86_64.qcow2 | openstack image create fedora-heat-test-image --disk-format qcow2 --container-format bare --public
+if [[ ${PIPESTATUS[0]} -ne 0 ]]; then
+   # The curl command failed, so the upload is mostly likely incorrect. Let's
+   # bail out early.
+   exit 1
+fi
+
 iniset heat_integrationtests.conf DEFAULT image_ref fedora-heat-test-image
 iniset heat_integrationtests.conf DEFAULT boot_config_env $DEST/heat-templates/hot/software-config/boot-config/test_image_env.yaml
 iniset heat_integrationtests.conf DEFAULT heat_config_notify_script $DEST/heat-templates/hot/software-config/elements/heat-config/bin/heat-config-notify
